def bytes_to_string(b: bytes) -> str:
    """
    bytes转字符串
    :param b: 字节列表
    :return:
    """


def utf8(charset: str, text: str) -> str:
    """
    将其他字符集文本转换为utf8
    :param charset: 源文本使用的字符集
    :param text: 源文本
    :return:
    """
